@@ -5,6 +5,14 @@ import (
 	"reflect"
 	"time"
 
+	"github.com/openshift/cluster-image-registry-operator/defaults"
+	"github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/metrics"
+	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+	"github.com/openshift/cluster-image-registry-operator/pkg/resource/object"
+	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
+
+	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metaapi "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
@@ -12,14 +20,6 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/util/retry"
 	"k8s.io/klog"
-
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/pkg/client"
-	"github.com/openshift/cluster-image-registry-operator/pkg/metrics"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
-	"github.com/openshift/cluster-image-registry-operator/pkg/resource/object"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
 )
 
 func ApplyMutator(gen Mutator) error {
@@ -93,8 +93,10 @@ func (g *Generator) listRoutes(cr *imageregistryv1.Config) []Mutator {
 
 func (g *Generator) List(cr *imageregistryv1.Config) ([]Mutator, error) {
 	driver, err := storage.NewDriver(&cr.Spec.Storage, g.kubeconfig, g.listers)
-	if err != nil {
+	if err != nil && err != storage.ErrStorageNotConfigured {
 		return nil, err
+	} else if err == storage.ErrStorageNotConfigured {
+		klog.V(6).Info("storage not configured, some mutators might not work.")
 	}
 
 	var mutators []Mutator
@@ -122,6 +124,13 @@ func (g *Generator) syncStorage(cr *imageregistryv1.Config) error {
 	var runCreate bool
 	// Create a driver with the current configuration
 	driver, err := storage.NewDriver(&cr.Spec.Storage, g.kubeconfig, g.listers)
+	if err == storage.ErrStorageNotConfigured {
+		cr.Spec.Storage, _, err = storage.GetPlatformStorage(g.listers)
+		if err != nil {
+			return fmt.Errorf("unable to get storage configuration from cluster install config: %s", err)
+		}
+		driver, err = storage.NewDriver(&cr.Spec.Storage, g.kubeconfig, g.listers)
+	}
 	if err != nil {
 		return err
 	}
@@ -148,19 +157,6 @@ func (g *Generator) syncStorage(cr *imageregistryv1.Config) error {
 		}
 	}
 
-	// XXX BZ 1722878
-	// This is a workaround for a bug that affected OCP 4.2 and earlier. We
-	// may have multiple storage engines set on Status, that is not a valid
-	// situation. Here we check if this is the case and if yes we fix it by
-	// copying what we have on the Spec into the Status.
-	_, err = storage.NewDriver(
-		&cr.Status.Storage, g.kubeconfig, g.listers,
-	)
-	if _, ok := err.(*storage.MultiStoragesError); ok {
-		specCopy := cr.Spec.Storage.DeepCopy()
-		cr.Status.Storage = *specCopy
-	}
-
 	return nil
 }
 
@@ -274,7 +270,9 @@ func (g *Generator) Remove(cr *imageregistryv1.Config) error {
 	}
 
 	driver, err := storage.NewDriver(&cr.Status.Storage, g.kubeconfig, g.listers)
-	if err != nil {
+	if err == storage.ErrStorageNotConfigured {
+		return nil
+	} else if err != nil {
 		return err
 	}
 
@@ -294,5 +292,7 @@ func (g *Generator) Remove(cr *imageregistryv1.Config) error {
 		return fmt.Errorf("unable to remove storage: %s, %s", err, derr)
 	}
 
+	cr.Status.Storage = imageregistryv1.ImageRegistryConfigStorage{}
+
 	return nil
 }
