@@ -18,13 +18,14 @@ import (
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/client-go/rest"
 
 	configapiv1 "github.com/openshift/api/config/v1"
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
+
 	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 	"github.com/openshift/cluster-image-registry-operator/version"
 )
@@ -37,25 +38,23 @@ type S3 struct {
 }
 
 type driver struct {
-	Context    context.Context
-	Config     *imageregistryv1.ImageRegistryConfigStorageS3
-	KubeConfig *rest.Config
-	Listers    *regopclient.Listers
+	Context context.Context
+	Config  *imageregistryv1.ImageRegistryConfigStorageS3
+	Listers *regopclient.Listers
 }
 
 // NewDriver creates a new s3 storage driver
 // Used during bootstrapping
-func NewDriver(ctx context.Context, c *imageregistryv1.ImageRegistryConfigStorageS3, kubeconfig *rest.Config, listers *regopclient.Listers) *driver {
+func NewDriver(ctx context.Context, c *imageregistryv1.ImageRegistryConfigStorageS3, listers *regopclient.Listers) *driver {
 	return &driver{
-		Context:    ctx,
-		Config:     c,
-		KubeConfig: kubeconfig,
-		Listers:    listers,
+		Context: ctx,
+		Config:  c,
+		Listers: listers,
 	}
 }
 
 // GetConfig reads configuration for the S3 cloud platform services.
-func GetConfig(kubeconfig *rest.Config, listers *regopclient.Listers) (*S3, error) {
+func GetConfig(listers *regopclient.Listers) (*S3, error) {
 	cfg := &S3{}
 
 	infra, err := util.GetInfrastructure(listers)
@@ -108,7 +107,7 @@ func GetConfig(kubeconfig *rest.Config, listers *regopclient.Listers) (*S3, erro
 // getS3Service returns a client that allows us to interact
 // with the aws S3 service
 func (d *driver) getS3Service() (*s3.S3, error) {
-	cfg, err := GetConfig(d.KubeConfig, d.Listers)
+	cfg, err := GetConfig(d.Listers)
 	if err != nil {
 		return nil, err
 	}
@@ -130,6 +129,7 @@ func (d *driver) getS3Service() (*s3.S3, error) {
 			},
 		},
 	}
+	awsConfig.WithUseDualStack(true)
 	if d.Config.RegionEndpoint != "" {
 		awsConfig.WithS3ForcePathStyle(true)
 		awsConfig.WithEndpoint(d.Config.RegionEndpoint)
@@ -171,50 +171,36 @@ func isBucketNotFound(err interface{}) bool {
 
 // ConfigEnv configures the environment variables that will be
 // used in the image registry deployment
-func (d *driver) ConfigEnv() (envs []corev1.EnvVar, err error) {
+func (d *driver) ConfigEnv() (envs envvar.List, err error) {
+	cfg, err := GetConfig(d.Listers)
+	if err != nil {
+		return nil, err
+	}
+
 	if len(d.Config.RegionEndpoint) != 0 {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_S3_REGIONENDPOINT", Value: d.Config.RegionEndpoint})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_REGIONENDPOINT", Value: d.Config.RegionEndpoint})
 	}
 
 	if len(d.Config.KeyID) != 0 {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_S3_KEYID", Value: d.Config.KeyID})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_KEYID", Value: d.Config.KeyID})
 	}
 
 	envs = append(envs,
-		corev1.EnvVar{Name: "REGISTRY_STORAGE", Value: "s3"},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_S3_BUCKET", Value: d.Config.Bucket},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_S3_REGION", Value: d.Config.Region},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_S3_ENCRYPT", Value: fmt.Sprintf("%v", d.Config.Encrypt)},
-		corev1.EnvVar{
-			Name: "REGISTRY_STORAGE_S3_ACCESSKEY",
-			ValueFrom: &corev1.EnvVarSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: defaults.ImageRegistryPrivateConfiguration,
-					},
-					Key: "REGISTRY_STORAGE_S3_ACCESSKEY",
-				},
-			},
-		},
-		corev1.EnvVar{
-			Name: "REGISTRY_STORAGE_S3_SECRETKEY",
-			ValueFrom: &corev1.EnvVarSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: defaults.ImageRegistryPrivateConfiguration,
-					},
-					Key: "REGISTRY_STORAGE_S3_SECRETKEY",
-				},
-			},
-		},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE", Value: "s3"},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_BUCKET", Value: d.Config.Bucket},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_REGION", Value: d.Config.Region},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_ENCRYPT", Value: d.Config.Encrypt},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_USEDUALSTACK", Value: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_ACCESSKEY", Value: cfg.AccessKey, Secret: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_S3_SECRETKEY", Value: cfg.SecretKey, Secret: true},
 	)
 
 	if d.Config.CloudFront != nil {
 		envs = append(envs,
-			corev1.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_BASEURL", Value: d.Config.CloudFront.BaseURL},
-			corev1.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_KEYPAIRID", Value: d.Config.CloudFront.KeypairID},
-			corev1.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_DURATION", Value: d.Config.CloudFront.Duration.String()},
-			corev1.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_PRIVATEKEY", Value: "/etc/docker/cloudfront/private.pem"},
+			envvar.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_BASEURL", Value: d.Config.CloudFront.BaseURL},
+			envvar.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_KEYPAIRID", Value: d.Config.CloudFront.KeypairID},
+			envvar.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_DURATION", Value: d.Config.CloudFront.Duration.String()},
+			envvar.EnvVar{Name: "REGISTRY_MIDDLEWARE_STORAGE_CLOUDFRONT_PRIVATEKEY", Value: "/etc/docker/cloudfront/private.pem"},
 		)
 	}
 
@@ -250,17 +236,8 @@ func (d *driver) Volumes() ([]corev1.Volume, []corev1.VolumeMount, error) {
 	return []corev1.Volume{vol}, []corev1.VolumeMount{mount}, nil
 }
 
-// Secrets returns a map of the storage access secrets.
-func (d *driver) Secrets() (map[string]string, error) {
-	cfg, err := GetConfig(d.KubeConfig, d.Listers)
-	if err != nil {
-		return nil, err
-	}
-
-	return map[string]string{
-		"REGISTRY_STORAGE_S3_ACCESSKEY": cfg.AccessKey,
-		"REGISTRY_STORAGE_S3_SECRETKEY": cfg.SecretKey,
-	}, nil
+func (d *driver) VolumeSecrets() (map[string]string, error) {
+	return nil, nil
 }
 
 // bucketExists checks whether or not the s3 bucket exists
